django-slack
============

|CodeSponsorLink|_

.. |CodeSponsorLink| image:: https://app.codesponsor.io/embed/9AxZ8p5j1kuTrGA7HFn5tCJs/lamby/django-slack.svg
.. _CodeSponsorLink: https://app.codesponsor.io/link/9AxZ8p5j1kuTrGA7HFn5tCJs/lamby/django-slack

* Documentation: https://django-slack.readthedocs.org/
* Homepage: https://chris-lamb.co.uk/projects/django-slack

----

**Consulting services**: if your organisation needs a reputable software developer with a track record of producing high-quality and maintainable Python/Django code, please get in touch to discuss your needs. `More info <https://chris-lamb.co.uk/services>`_
